pub type NestedKey = (ElementKey, Vec<(String, usize)>);Expand description
A nested-list element: its entity element, and its position in the lists
below it ([("zuordnungen", 3)]).
pub type NestedKey = (ElementKey, Vec<(String, usize)>);A nested-list element: its entity element, and its position in the lists
below it ([("zuordnungen", 3)]).