Module evaluator_factory

Module evaluator_factory 

Factory for creating condition evaluators by variant name and format version.

Functions

create_evaluator
Create a condition evaluator for the given variant and format version.
validate_with_boxed_evaluator
Run condition-aware validation using a boxed evaluator.