Factory for creating condition evaluators by variant name and format version.
Functions
- create_
evaluator - Create a condition evaluator for the given variant and format version.
- validate_
with_ boxed_ evaluator - Run condition-aware validation using a boxed evaluator.