pub fn create_evaluator(
variant: &str,
fv: &str,
) -> Option<Box<dyn ConditionEvaluator>>Expand description
Create a condition evaluator for the given variant and format version.
Returns None if no evaluator exists for the combination. See
automapper_validation::evaluator_for.